"""
nuqql config
"""

from .config import \
        init, \
        parse_args
from .configs import get
from .winconfig import DEFAULT_KEYMAP, WinConfig
